operator [] method

  1. @override
V? operator [](
  1. Object? key
)
override

The value for the given key, or null if key is not in the map.

Some maps allow null as a value. For those maps, a lookup using this operator cannot distinguish between a key not being in the map, and the key being there with a null value. Methods like containsKey or putIfAbsent can be used if the distinction is important.

Implementation

@override
V? operator [](Object? key) {
  if (key is String) {
    final nativeKey = toNativeString(key);
    try {
      final value = _stringMapGetValue(_ptr, nativeKey);
      if (value == nullptr) {
        return null;
      }
      return _fromValue(value);
    } finally {
      malloc.free(nativeKey.ptr);
    }
  }
  return null;
}