BitmapRegionDecoder$Impl class

Implemented types

Constructors

BitmapRegionDecoder$Impl(Pointer<Void> handle)

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
Height of the source image in pixels (after header parse / decode metadata).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Width of the source image in pixels (after header parse / decode metadata).
no setteroverride

Methods

decodeRegion(Rectangle rect, double sampleSize) ImageWrapper
Method is used to decode rectangle region in the image specified by rect. rect area to render Rectangle sampleSize if set to a value > 1, requests the decoder to subsample the original image, returning a smaller image to save memory. Returns constructed bitmap
override
newInstance(Uint8List data) BitmapRegionDecoder
Method is used to create instance of BitmapRegionDecoder data raw image data (could be raw svg string) Returns nstance of decoder, which could be used for decoding byte array to bitmap.
override
newInstanceFromImage(Image data) BitmapRegionDecoder
Creates decoder from Image without copying raw bytes again. data image instance (e.g. from SDK pipeline); must remain valid while decoder is used Returns decoder instance or null on error
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited