BitmapRegionDecoder class abstract
@ingroup navigine_dart_classes @ingroup navigine_dart_secondary_classes @brief Class is used for getting bitmaps (png, jpg, svg) from byte array.
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
@brief Height of the source image in pixels (after header parse / decode metadata).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
@brief Width of the source image in pixels (after header parse / decode metadata).
no setter
Methods
-
decodeRegion(
Rectangle rect, double sampleSize) → ImageWrapper - @brief Method is used to decode rectangle region in the image specified by rect. @param rect area to render @see Rectangle "Rectangle" @param sampleSize if set to a value > 1, requests the decoder to subsample the original image, returning a smaller image to save memory. @return constructed bitmap
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
newInstance(
Uint8List data) → BitmapRegionDecoder - @brief Method is used to create instance of BitmapRegionDecoder @param data raw image data (could be raw svg string) @return nstance of decoder, which could be used for decoding byte array to bitmap.
-
newInstanceFromImage(
Image data) → BitmapRegionDecoder - @brief Creates decoder from @see Image "Image" without copying raw bytes again. @param data image instance (e.g. from SDK pipeline); must remain valid while decoder is used @return decoder instance or null on error