setPosition method
Method is used to specify the center of the circle.
point Metrics coordinates of the center LocationPoint.
Returns true if the operation is successful, false otherwise.
Example:
// Set circle position
LocationPoint centerPoint = LocationPoint(100.0, 200.0);
bool success = _circleMapObject!.setPosition(centerPoint);
print(
"Set circle position to (${centerPoint.x}, ${centerPoint.y}): $success",
);
Implementation
@override
bool setPosition(LocationPoint point) {
final _setPositionFfi = __lib.catchArgumentError(() => __lib.nativeLibrary.lookupFunction<
Uint8 Function(Pointer<Void>, Pointer<Void>),
int Function(Pointer<Void>, Pointer<Void>)
>('navigine_sdk_flutter_CircleMapObject_setPosition__Point'));
final _pointHandle = navigine_sdk_flutter_LocationPoint_ToFfi(point);
final _handle = this.handle;
final __resultHandle = _setPositionFfi(_handle, _pointHandle);
navigine_sdk_flutter_LocationPoint_ReleaseFfiHandle(_pointHandle);
final _result = navigine_sdk_flutter_bool_FromFfi(__resultHandle);
navigine_sdk_flutter_bool_ReleaseFfiHandle(__resultHandle);
return _result;
}