removeIconMapObject method

  1. @override
bool removeIconMapObject(
  1. IconMapObject iconMapObject
)
override

Removes an icon map object from the cluster controller. iconMapObject Icon to remove. Returns true if the icon was removed, false otherwise.

Example:

final removed = controller.removeIconMapObject(clusterIcon1);
print("Removed icon from cluster controller: $removed");

Implementation

@override
bool removeIconMapObject(IconMapObject iconMapObject) {
    final _removeIconMapObjectFfi = __lib.catchArgumentError(() => __lib.nativeLibrary.lookupFunction<
        Uint8 Function(Pointer<Void>, Pointer<Void>),
        int Function(Pointer<Void>, Pointer<Void>)
      >('navigine_sdk_flutter_ClusterMapObjectController_removeIconMapObject__IconMapObject'));
    final __resultHandle = _removeIconMapObjectFfi(this.ptr, IconMapObject$Impl.getNativePtr(iconMapObject));
    final _result = (__resultHandle != 0);
    exception.checkCallResult();
    return _result;
}