removeIconMapObject abstract method

bool removeIconMapObject(
  1. IconMapObject iconMapObject
)

Removes an icon map object from the cluster controller. iconMapObject Icon to remove. Returns true if the icon was removed, false otherwise.

Example:

final removed = controller.removeIconMapObject(clusterIcon1);
print("Removed icon from cluster controller: $removed");

Implementation

bool removeIconMapObject(IconMapObject iconMapObject);