removeModelMapObject method

  1. @override
bool removeModelMapObject(
  1. ModelMapObject modelMapObject
)
override

Removes a model map object from the location view. modelMapObject The model instance to remove ModelMapObject. Returns true if the operation is successful, false otherwise.

Example:

bool removed = _locationWindow!.removeModelMapObject(m);
print("Removed model map object: $removed");
_modelMapObject = null;

Implementation

@override
bool removeModelMapObject(ModelMapObject modelMapObject) {
    final _removeModelMapObjectFfi = __lib.catchArgumentError(() => __lib.nativeLibrary.lookupFunction<
        Uint8 Function(Pointer<Void>, Pointer<Void>),
        int Function(Pointer<Void>, Pointer<Void>)
      >('navigine_sdk_flutter_LocationWindow_removeModelMapObject__ModelMapObject'));
    final __resultHandle = _removeModelMapObjectFfi(this.ptr, ModelMapObject$Impl.getNativePtr(modelMapObject));
    final _result = (__resultHandle != 0);
    exception.checkCallResult();
    return _result;
}