removeModelMapObject abstract method

bool removeModelMapObject(
  1. ModelMapObject modelMapObject
)

Removes a model map object from the location view. modelMapObject The model instance to remove ModelMapObject. Returns true if the operation is successful, false otherwise.

Example:

bool removed = _locationWindow!.removeModelMapObject(m);
print("Removed model map object: $removed");
_modelMapObject = null;

Implementation

bool removeModelMapObject(ModelMapObject modelMapObject);