MapObject$Impl class

Implemented types

Constructors

MapObject$Impl(Pointer<Void> handle)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getData() Uint8List
Gets the user-defined data associated with the map object. Returns The data stored in the map object.
override
getId() int
Gets the unique identifier of the map object. Returns The unique identifier of the map object.
override
getType() MapObjectType
Gets the type of the map object. Returns The type of the map object MapObjectType.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAlpha(double alpha) bool
Method is used to set the opacity of the map object. alpha Opacity multiplier. Values below 0 will be set to 0. Values above 1 will be set to 1. Default: 1. Returns true if the operation is successful, false otherwise.
override
setData(Uint8List data) → void
Method is used to set user-defined data for the map object. data Data to store in the map object.
override
setInteractive(bool interactive) bool
Method is used to specify whether the map object can be interacted with. interactive Specifies whether the object can be picked in the pickMapObjectAt method (true) or not (false). Default: false. Returns true if the operation is successful, false otherwise.
override
setTitle(String title) bool
Method is used to set the title of the map object. title The title to display on the location view. Returns true if the operation is successful, false otherwise.
override
setVisible(bool visible) bool
Method is used to specify the visibility of the map object. visible Specifies whether the object is visible (true) or hidden (false). Default: true. Returns true if the operation is successful, false otherwise.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited