setAlpha abstract method
Method is used to set the opacity of the map object.
alpha Opacity multiplier. Values below 0 will be set to 0. Values above 1 will be set to 1. Default: 1.
Returns true if the operation is successful, false otherwise.
Example:
// Set alpha transparency
bool alphaSuccess = _circleMapObject!.setAlpha(0.7);
print("Set circle alpha to 0.7: $alphaSuccess");
Implementation
bool setAlpha(double alpha);