setInteractive abstract method
Method is used to specify whether the map object can be interacted with.
interactive Specifies whether the object can be picked in the pickMapObjectAt method (true) or not (false). Default: false.
Returns true if the operation is successful, false otherwise.
Example:
// Set interactive mode
bool interactiveSuccess = _circleMapObject!.setInteractive(true);
print("Set circle interactive to true: $interactiveSuccess");
Implementation
bool setInteractive(bool interactive);