ModelMapObject$Impl class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getData()
→ Uint8List
-
@brief Gets the user-defined data associated with the map object.
@return The data stored in the map object.
override
-
getId()
→ int
-
@brief Gets the unique identifier of the map object.
@return The unique identifier of the map object.
override
-
getType()
→ MapObjectType
-
@brief Gets the type of the map object.
@return The type of the map object @see MapObjectType "MapObjectType".
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setAlpha(double alpha)
→ bool
-
@brief Method is used to set the opacity of the map object.
@param alpha Opacity multiplier. Values below 0 will be set to 0. Values above 1 will be set to 1. Default: 1.
@return true if the operation is successful, false otherwise.
override
-
setAngle(double angle)
→ bool
-
@brief Sets rotation angle in degrees (around the placement axis used by the engine).
@return true if the operation is successful, false otherwise.
override
-
setAngleAnimated(double angle, double duration, AnimationType type)
→ bool
-
@brief Animates rotation to the given angle.
@return true if the operation is successful, false otherwise.
override
-
setBuffer(double width, double height)
→ bool
-
@brief Extra hit-test padding around the model in pixels.
@return true if the operation is successful, false otherwise.
override
-
setCollisionEnabled(bool enabled)
→ bool
-
@brief Enables or disables collision tests for this object.
@return true if the operation is successful, false otherwise.
override
-
setData(Uint8List data)
→ void
-
@brief Method is used to set user-defined data for the map object.
@param data Data to store in the map object.
override
-
setInteractive(bool interactive)
→ bool
-
@brief Method is used to specify whether the map object can be interacted with.
@param interactive Specifies whether the object can be picked in the
pickMapObjectAt method (true) or not (false). Default: false.
@return true if the operation is successful, false otherwise.
override
-
setModel(ModelProvider model)
→ bool
-
@brief Sets the 3D asset (OBJ source + texture ImageProvider).
@param model Model provider @see ModelProvider "ModelProvider".
@return true if the operation is successful, false otherwise.
override
-
setPosition(LocationPoint point)
→ bool
-
@brief Sets the anchor position of the model in metric coordinates.
@param point Center / placement point @see LocationPoint "LocationPoint".
@return true if the operation is successful, false otherwise.
override
-
setPositionAnimated(LocationPoint point, double duration, AnimationType type)
→ bool
-
@brief Animates the model anchor to a new position.
@param point Target metrics coordinates @see LocationPoint "LocationPoint".
@param duration Animation duration in seconds.
@param type Animation easing @see AnimationType "AnimationType".
@return true if the operation is successful, false otherwise.
override
-
setPriority(double priority)
→ bool
-
@brief Render order priority (higher draws above).
@return true if the operation is successful, false otherwise.
override
-
setSize(double width, double height)
→ bool
-
@brief Sets the on-screen size of the model in pixels (width and height).
@return true if the operation is successful, false otherwise.
override
-
setTitle(String title)
→ bool
-
@brief Method is used to set the title of the map object.
@param title The title to display on the location view.
@return true if the operation is successful, false otherwise.
override
-
setVisible(bool visible)
→ bool
-
@brief Method is used to specify the visibility of the map object.
@param visible Specifies whether the object is visible (true) or hidden (false). Default: true.
@return true if the operation is successful, false otherwise.
override
-
toString()
→ String
-
A string representation of this object.
inherited