setPositionAnimated abstract method

bool setPositionAnimated(
  1. LocationPoint point,
  2. double duration,
  3. AnimationType type
)

@brief Animates the model anchor to a new position. @param point Target metrics coordinates @see LocationPoint "LocationPoint". @param duration Animation duration in seconds. @param type Animation easing @see AnimationType "AnimationType". @return true if the operation is successful, false otherwise.

Dart code snippet: @snippet location_window_map_objects_example.dart dart_ModelMapObject_setPositionAnimated

Implementation

bool setPositionAnimated(LocationPoint point, double duration, AnimationType type);