DefaultNavigationViewConfig class

@ingroup navigine_dart_classes @ingroup navigine_dart_default_navigation_view

@brief Configuration for DefaultNavigationView. Controls visibility of built-in widgets.

@snippet DefaultNavigationView/dart/default_navigation_view_example.dart dart_DefaultNavigationView_config

Constructors

DefaultNavigationViewConfig({int visibleWidgets = NavigationWidgetVisibility.all})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleWidgets int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited