NativeImageProviderWrapper class

Implemented types
Available extensions

Constructors

NativeImageProviderWrapper(Pointer<Void> rawPointer)

Properties

cacheable bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
no setteroverride
rawPointer Pointer<Void>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited