ClusterMapObjectController$Impl class
- Implemented types
Constructors
Properties
Methods
-
addIconMapObject(
IconMapObject iconMapObject) → bool -
Adds an icon map object to the cluster controller.
iconMapObjectIcon to cluster IconMapObject. Must be added to the same LocationWindow viaaddIconMapObject. Returns true if the icon was added, false otherwise.override -
addListener(
ClusterMapObjectControllerListener listener) → void -
Adds a listener for cluster lifecycle events ClusterMapObjectControllerListener.
listenerListener instance.override -
clear(
) → void -
Removes all icon map objects from the controller and destroys visible cluster markers.
override
-
getClusters(
) → List< ClusterMapObject> -
Returns a snapshot of currently visible clusters.
override
-
getRadius(
) → double -
Returns cluster radius in density-independent pixels.
override
-
isEnabled(
) → bool -
Returns whether clustering is enabled.
override
-
isValid(
) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeIconMapObject(
IconMapObject iconMapObject) → bool -
Removes an icon map object from the cluster controller.
iconMapObjectIcon to remove. Returns true if the icon was removed, false otherwise.override -
removeListener(
ClusterMapObjectControllerListener listener) → void -
Removes a previously added listener.
listenerListener instance to remove.override -
setClusterSize(
double width, double height) → bool -
Specifies the size of the default cluster icon in pixels.
Returns true if the operation is successful, false otherwise.
override
-
setEnabled(
bool enabled) → void -
Enables or disables clustering. Default: true.
override
-
setInteractive(
bool interactive) → bool -
Specifies whether cluster markers can be picked. Default: true.
Returns true if the operation is successful, false otherwise.
override
-
setRadius(
double radius) → void -
Cluster radius in density-independent pixels. Default: 40.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited