setPosition abstract method
Sets the anchor position of the model in metric coordinates.
point Center / placement point LocationPoint.
Returns true if the operation is successful, false otherwise.
Example:
bool posOk = m.setPosition(LocationPoint(12.0, 34.0));
print("Model setPosition: $posOk");
Implementation
bool setPosition(LocationPoint point);