DefaultNavigationViewController class
@ingroup navigine_dart_classes @ingroup navigine_dart_default_navigation_view
@brief Controller for runtime config updates. When configs change and notifyListeners is called, DefaultNavigationView rebuilds. Widget configs are passed directly to each widget.
@snippet DefaultNavigationView/dart/default_navigation_view_example.dart dart_DefaultNavigationView_runtimeConfig
- Inheritance
-
- Object
- ChangeNotifier
- DefaultNavigationViewController
Constructors
Properties
- floorSelectorConfig → FloorSelectorViewConfig
-
no setter
- followMeButtonConfig → FollowMeButtonConfig
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewConfig → DefaultNavigationViewConfig
-
no setter
- zoomControlsConfig → ZoomControlsConfig
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateConfig(
{DefaultNavigationViewConfig? viewConfig, ZoomControlsConfig? zoomConfig, FollowMeButtonConfig? followMeConfig, FloorSelectorViewConfig? floorConfig}) → void - Updates configs at runtime. null params keep current config.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited